==> public-sdk-2.0.71.7-sources.jar: com/voxeet/sdk/core/services/NotificationService.java <==
package com.voxeet.sdk.core.services;

import android.content.Context;
import android.os.Build;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.voxeet.push.center.NotificationCenterFactory;
import com.voxeet.push.center.invitation.IIncomingInvitationListener;
import com.voxeet.push.center.invitation.InvitationBundle;
import com.voxeet.push.center.management.EnforcedNotificationMode;
import com.voxeet.push.center.management.NotificationMode;
import com.voxeet.push.center.management.VersionFilter;
import com.voxeet.push.utils.Annotate;
import com.voxeet.sdk.core.AbstractVoxeetService;
import com.voxeet.sdk.core.VoxeetSdk;
import com.voxeet.sdk.core.services.holder.ServiceProviderHolder;

/**
 * Service used to :
 * - register listener for specific notification mode
 *  - FullScreen
 *  - Overhead Notification
 *  - ...or none
 * - register filters which will reject a specific mode after a following mix of platforms and version (note: all manufacturers : VersionFilter.ALL)
 * - set the current "enforced notification mode", the mode that will be used to display
 * - let developers forward custom incoming invitation or conference rejection/dismiss
 */
@Annotate
public class NotificationService extends AbstractVoxeetService {

    public NotificationService(@NonNull VoxeetSdk instance) {
        super(instance, ServiceProviderHolder.DEFAULT);
    }

    @NonNull
    public NotificationService setEnforcedNotificationMode(@NonNull EnforcedNotificationMode enforcedNotificationMode) {
        NotificationCenterFactory.instance.setEnforcedNotificationMode(enforcedNotificationMode);
        return this;
    }

    @NonNull
    public NotificationService register(@NonNull NotificationMode notificationMode, @Nullable IIncomingInvitationListener invitationProvider) {
        NotificationCenterFactory.instance.register(notificationMode, invitationProvider);
        return this;
    }

    @NonNull
    public NotificationService register(@NonNull NotificationMode notificationMode, @NonNull VersionFilter filter) {
        NotificationCenterFactory.instance.register(notificationMode, filter);
        return this;
    }

    public void onInvitationReceived(@NonNull Context context,
                                               @NonNull InvitationBundle invitationBundle) {
        NotificationCenterFactory.instance.onInvitationReceived(context,
                invitationBundle.asMap(),
                Build.MANUFACTURER,
                Build.VERSION.SDK_INT);
    }

    @NonNull
    public String onInvitationCanceledReceived(@NonNull Context context,
                                               @NonNull InvitationBundle invitationBundle) {
        return NotificationCenterFactory.instance.onInvitationCanceledReceived(context,
                invitationBundle.asMap(),
                Build.MANUFACTURER,
                Build.VERSION.SDK_INT);
    }

}

==> public-sdk-2.0.72-sources.jar: com/voxeet/sdk/core/services/NotificationService.java <==
package com.voxeet.sdk.core.services;

import android.content.Context;
import android.os.Build;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.voxeet.push.center.NotificationCenterFactory;
import com.voxeet.push.center.invitation.IIncomingInvitationListener;
import com.voxeet.push.center.invitation.InvitationBundle;
import com.voxeet.push.center.management.EnforcedNotificationMode;
import com.voxeet.push.center.management.NotificationMode;
import com.voxeet.push.center.management.VersionFilter;
import com.voxeet.push.utils.Annotate;
import com.voxeet.sdk.core.AbstractVoxeetService;
import com.voxeet.sdk.core.VoxeetSdk;
import com.voxeet.sdk.core.services.holder.ServiceProviderHolder;
import com.voxeet.sdk.core.services.notification.INotificationTokenProvider;
import com.voxeet.sdk.core.services.notification.NotificationTokenHolderFactory;

/**
 * Service used to :
 * - register listener for specific notification mode
 * - FullScreen
 * - Overhead Notification
 * - ...or none
 * - register filters which will reject a specific mode after a following mix of platforms and version (note: all manufacturers : VersionFilter.ALL)
 * - set the current "enforced notification mode", the mode that will be used to display
 * - let developers forward custom incoming invitation or conference rejection/dismiss
 */
@Annotate
public class NotificationService extends AbstractVoxeetService {

    public NotificationService(@NonNull VoxeetSdk instance) {
        super(instance, ServiceProviderHolder.DEFAULT);
    }

    @Nullable
    public INotificationTokenProvider getNotificationTokenProvider() {
        return NotificationTokenHolderFactory.provider;
    }

    @NonNull
    public NotificationService setNotificationTokenProvider(@Nullable INotificationTokenProvider provider) {
        NotificationTokenHolderFactory.provider = provider;
        return this;
    }

    @NonNull
    public NotificationService setEnforcedNotificationMode(@NonNull EnforcedNotificationMode enforcedNotificationMode) {
        NotificationCenterFactory.instance.setEnforcedNotificationMode(enforcedNotificationMode);
        return this;
    }

    @NonNull
    public NotificationService register(@NonNull NotificationMode notificationMode, @Nullable IIncomingInvitationListener invitationProvider) {
        NotificationCenterFactory.instance.register(notificationMode, invitationProvider);
        return this;
    }

    @NonNull
    public NotificationService register(@NonNull NotificationMode notificationMode, @NonNull VersionFilter filter) {
        NotificationCenterFactory.instance.register(notificationMode, filter);
        return this;
    }

    public void onInvitationReceived(@NonNull Context context,
                                     @NonNull InvitationBundle invitationBundle) {
        NotificationCenterFactory.instance.onInvitationReceived(context,
                invitationBundle.asMap(),
                Build.MANUFACTURER,
                Build.VERSION.SDK_INT);
    }

    @NonNull
    public String onInvitationCanceledReceived(@NonNull Context context,
                                               @NonNull InvitationBundle invitationBundle) {
        return NotificationCenterFactory.instance.onInvitationCanceledReceived(context,
                invitationBundle.asMap(),
                Build.MANUFACTURER,
                Build.VERSION.SDK_INT);
    }

}
